@@ -5,7 +5,7 @@
 ///          Foo some_parameter = 1;
 ///          PageRequest pagination = 2;
 ///  }
-#[derive(Clone, PartialEq, ::prost::Message)]
+#[derive(::serde::Serialize, ::serde::Deserialize, Clone, PartialEq, ::prost::Message)]
 pub struct PageRequest {
     /// key is a value returned in PageResponse.next_key to begin
     /// querying the next page most efficiently. Only one of offset or key
@@ -28,6 +28,8 @@ pub struct PageRequest {
     #[prost(bool, tag = "4")]
     pub count_total: bool,
     /// reverse is set to true if results are to be returned in the descending order.
+    ///
+    /// Since: cosmos-sdk 0.43
     #[prost(bool, tag = "5")]
     pub reverse: bool,
 }
@@ -38,7 +40,7 @@ pub struct PageRequest {
 ///          repeated Bar results = 1;
 ///          PageResponse page = 2;
 ///  }
-#[derive(Clone, PartialEq, ::prost::Message)]
+#[derive(::serde::Serialize, ::serde::Deserialize, Clone, PartialEq, ::prost::Message)]
 pub struct PageResponse {
     /// next_key is the key to be passed to PageRequest.key to
     /// query the next page most efficiently
