@@ -1,4 +1,6 @@
 /// WeightedVoteOption defines a unit of vote for vote split.
+///
+/// Since: cosmos-sdk 0.43
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct WeightedVoteOption {
     #[prost(enumeration = "VoteOption", tag = "1")]
@@ -32,21 +34,21 @@ pub struct Proposal {
     #[prost(uint64, tag = "1")]
     pub proposal_id: u64,
     #[prost(message, optional, tag = "2")]
-    pub content: ::core::option::Option<::prost_types::Any>,
+    pub content: ::core::option::Option<super::super::super::google::protobuf::Any>,
     #[prost(enumeration = "ProposalStatus", tag = "3")]
     pub status: i32,
     #[prost(message, optional, tag = "4")]
     pub final_tally_result: ::core::option::Option<TallyResult>,
     #[prost(message, optional, tag = "5")]
-    pub submit_time: ::core::option::Option<::prost_types::Timestamp>,
+    pub submit_time: ::core::option::Option<super::super::super::google::protobuf::Timestamp>,
     #[prost(message, optional, tag = "6")]
-    pub deposit_end_time: ::core::option::Option<::prost_types::Timestamp>,
+    pub deposit_end_time: ::core::option::Option<super::super::super::google::protobuf::Timestamp>,
     #[prost(message, repeated, tag = "7")]
     pub total_deposit: ::prost::alloc::vec::Vec<super::super::base::v1beta1::Coin>,
     #[prost(message, optional, tag = "8")]
-    pub voting_start_time: ::core::option::Option<::prost_types::Timestamp>,
+    pub voting_start_time: ::core::option::Option<super::super::super::google::protobuf::Timestamp>,
     #[prost(message, optional, tag = "9")]
-    pub voting_end_time: ::core::option::Option<::prost_types::Timestamp>,
+    pub voting_end_time: ::core::option::Option<super::super::super::google::protobuf::Timestamp>,
 }
 /// TallyResult defines a standard tally for a governance proposal.
 #[derive(Clone, PartialEq, ::prost::Message)]
@@ -74,6 +76,7 @@ pub struct Vote {
     #[deprecated]
     #[prost(enumeration = "VoteOption", tag = "3")]
     pub option: i32,
+    /// Since: cosmos-sdk 0.43
     #[prost(message, repeated, tag = "4")]
     pub options: ::prost::alloc::vec::Vec<WeightedVoteOption>,
 }
@@ -86,14 +89,14 @@ pub struct DepositParams {
     ///  Maximum period for Atom holders to deposit on a proposal. Initial value: 2
     ///  months.
     #[prost(message, optional, tag = "2")]
-    pub max_deposit_period: ::core::option::Option<::prost_types::Duration>,
+    pub max_deposit_period: ::core::option::Option<super::super::super::google::protobuf::Duration>,
 }
 /// VotingParams defines the params for voting on governance proposals.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct VotingParams {
     ///  Length of the voting period.
     #[prost(message, optional, tag = "1")]
-    pub voting_period: ::core::option::Option<::prost_types::Duration>,
+    pub voting_period: ::core::option::Option<super::super::super::google::protobuf::Duration>,
 }
 /// TallyParams defines the params for tallying votes on governance proposals.
 #[derive(Clone, PartialEq, ::prost::Message)]
@@ -152,7 +155,7 @@ pub enum ProposalStatus {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MsgSubmitProposal {
     #[prost(message, optional, tag = "1")]
-    pub content: ::core::option::Option<::prost_types::Any>,
+    pub content: ::core::option::Option<super::super::super::google::protobuf::Any>,
     #[prost(message, repeated, tag = "2")]
     pub initial_deposit: ::prost::alloc::vec::Vec<super::super::base::v1beta1::Coin>,
     #[prost(string, tag = "3")]
@@ -178,6 +181,8 @@ pub struct MsgVote {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MsgVoteResponse {}
 /// MsgVoteWeighted defines a message to cast a vote.
+///
+/// Since: cosmos-sdk 0.43
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MsgVoteWeighted {
     #[prost(uint64, tag = "1")]
@@ -188,6 +193,8 @@ pub struct MsgVoteWeighted {
     pub options: ::prost::alloc::vec::Vec<WeightedVoteOption>,
 }
 /// MsgVoteWeightedResponse defines the Msg/VoteWeighted response type.
+///
+/// Since: cosmos-sdk 0.43
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MsgVoteWeightedResponse {}
 /// MsgDeposit defines a message to submit a deposit to an existing proposal.
@@ -204,6 +211,7 @@ pub struct MsgDeposit {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MsgDepositResponse {}
 #[doc = r" Generated client implementations."]
+#[cfg(feature = "client")]
 pub mod msg_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
@@ -293,6 +301,8 @@ pub mod msg_client {
             self.inner.unary(request.into_request(), path, codec).await
         }
         #[doc = " VoteWeighted defines a method to add a weighted vote on a specific proposal."]
+        #[doc = ""]
+        #[doc = " Since: cosmos-sdk 0.43"]
         pub async fn vote_weighted(
             &mut self,
             request: impl tonic::IntoRequest<super::MsgVoteWeighted>,
@@ -472,6 +482,7 @@ pub struct QueryTallyResultResponse {
     pub tally: ::core::option::Option<TallyResult>,
 }
 #[doc = r" Generated client implementations."]
+#[cfg(feature = "client")]
 pub mod query_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
